SchemaIndex
=========

This nbextension adds a database button to jupyter toolbar. Once clicked,
it shows a dialog to search for data soruces. This plugin use schemaindex
python package as its back end main library. This plugin offers:

 * Search capabilities for data sources
 * For the data source result, you can click "snippet" to generate the python
 code to a new cell. You can then execute the cell to preview the data.


Options
-------

The function of how to add data sources remains in original schemaindex package.


